DagDbContextPacketResponse

Struct DagDbContextPacketResponse 

pub struct DagDbContextPacketResponse {
Show 30 fields pub schema_version: String, pub tenant_id: String, pub namespace: String, pub idempotency_key: String, pub context_packet_id: String, pub route_id: String, pub receipt_hash: String, pub validation_status: ValidationStatus, pub council_status: CouncilReviewStatus, pub dag_finality_status: DagFinalityStatus, pub memory_refs: Vec<ContextPacketMemoryRef>, pub packet_hash: String, pub token_budget: u32, pub token_estimate: u32, pub created_new: bool, pub validation_report_id: Option<String>, pub council_decision_id: Option<String>, pub context_packet_mode: Option<String>, pub selection_warning: Option<String>, pub layered_mode: Option<String>, pub selected_layers: Option<Vec<ContextPacketLayerRef>>, pub selected_layer_edges: Option<Vec<ContextPacketLayerEdgeRef>>, pub layer_budget_report: Option<ContextPacketLayerBudgetReport>, pub flat_fallback_used: Option<bool>, pub layered_status: Option<String>, pub selected_graph_edges: Vec<DagDbSelectedGraphEdgeRef>, pub citation_refs: Vec<DagDbContextPacketCitationRef>, pub packet_metrics: Option<DagDbContextPacketMetrics>, pub boundaries: Option<DagDbContextPacketBoundaries>, pub packet_markdown: Option<String>,
}
Context packet response.

Fields

schema_version: String

Stable wire-contract version (dagdb_context_packet_response_v1).

tenant_id: Stringnamespace: Stringidempotency_key: Stringcontext_packet_id: Stringroute_id: Stringreceipt_hash: Stringvalidation_status: ValidationStatuscouncil_status: CouncilReviewStatusdag_finality_status: DagFinalityStatusmemory_refs: Vec<ContextPacketMemoryRef>packet_hash: Stringtoken_budget: u32token_estimate: u32created_new: boolvalidation_report_id: Option<String>council_decision_id: Option<String>context_packet_mode: Option<String>selection_warning: Option<String>layered_mode: Option<String>selected_layers: Option<Vec<ContextPacketLayerRef>>selected_layer_edges: Option<Vec<ContextPacketLayerEdgeRef>>layer_budget_report: Option<ContextPacketLayerBudgetReport>flat_fallback_used: Option<bool>layered_status: Option<String>selected_graph_edges: Vec<DagDbSelectedGraphEdgeRef>

Selected graph edges surfaced from the internal context packet. Empty on the no-database scaffold path; populated on the persistent (governed) path.

citation_refs: Vec<DagDbContextPacketCitationRef>

Citation references surfaced from the internal context packet. Empty on the no-database scaffold path; populated on the persistent (governed) path.

packet_metrics: Option<DagDbContextPacketMetrics>

Packet metrics surfaced from the internal context packet, when available.

boundaries: Option<DagDbContextPacketBoundaries>

Blocked-claim boundaries surfaced from the internal context packet, when available.

packet_markdown: Option<String>

Rendered agent-facing markdown surfaced from the internal context packet, when available.