pub struct DagDbGraphContextPacket {Show 14 fields
pub schema_version: String,
pub tenant_id: String,
pub namespace: String,
pub request_id: String,
pub task: String,
pub task_hash: String,
pub packet_hash: String,
pub selected_memory_refs: Vec<DagDbSelectedContextRef>,
pub selected_graph_edges: Vec<DagDbSelectedGraphEdgeRef>,
pub citation_refs: Vec<DagDbContextPacketCitationRef>,
pub packet_metrics: DagDbContextPacketMetrics,
pub boundaries: DagDbContextPacketBoundaries,
pub agent_usage_instructions: Vec<String>,
pub markdown: String,
}Expand description
Bounded graph context packet emitted by the Rust packet builder.
Fields
schema_version: Stringtenant_id: Stringnamespace: Stringrequest_id: Stringtask: Stringtask_hash: Stringpacket_hash: Stringselected_memory_refs: Vec<DagDbSelectedContextRef>selected_graph_edges: Vec<DagDbSelectedGraphEdgeRef>citation_refs: Vec<DagDbContextPacketCitationRef>packet_metrics: DagDbContextPacketMetricsboundaries: DagDbContextPacketBoundariesagent_usage_instructions: Vec<String>markdown: StringTrait Implementations
Sourceimpl Clone for DagDbGraphContextPacket
impl Clone for DagDbGraphContextPacket
Sourcefn clone(&self) -> DagDbGraphContextPacket
fn clone(&self) -> DagDbGraphContextPacket
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DagDbGraphContextPacket
impl Debug for DagDbGraphContextPacket
Sourceimpl<'de> Deserialize<'de> for DagDbGraphContextPacket
impl<'de> Deserialize<'de> for DagDbGraphContextPacket
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DagDbGraphContextPacket, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DagDbGraphContextPacket, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DagDbGraphContextPacket
Sourceimpl PartialEq for DagDbGraphContextPacket
impl PartialEq for DagDbGraphContextPacket
Sourcefn eq(&self, other: &DagDbGraphContextPacket) -> bool
fn eq(&self, other: &DagDbGraphContextPacket) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DagDbGraphContextPacket
impl Serialize for DagDbGraphContextPacket
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DagDbGraphContextPacket