pub fn send(registry: &PeerRegistry, msg: &Message) -> Result<()>Expand description
Send a message, verifying the recipient exists in the registry (if addressed).
pub fn send(registry: &PeerRegistry, msg: &Message) -> Result<()>Send a message, verifying the recipient exists in the registry (if addressed).