MessageReplayGuard

Struct MessageReplayGuard 

pub struct MessageReplayGuard { /* private fields */ }
Stateful acceptance guard for signed peer-to-peer messages.

Implementations

Source

impl MessageReplayGuard

pub const MAX_TRACKED_MESSAGES: usize = 4096

Maximum accepted messages tracked in a replay window.

pub fn new() -> Self

Create an empty replay guard.

pub fn len(&self) -> usize

Return the number of messages currently tracked in the replay window.

pub fn is_empty(&self) -> bool

Return true when no message keys are tracked.

pub fn reset(&mut self)

Reset the replay window.

pub fn verify_and_record( &mut self, msg: &Message, sender_public_key: &PublicKey, ) -> Result<()>

Verify a message signature and record its replay key after success.